=================
Functions
=================
.. currentmodule:: polars

Config
~~~~~~
.. autosummary::
   :toctree: api/

    toggle_string_cache
    StringCache

Conversion
~~~~~~~~~~
.. autosummary::
   :toctree: api/

    from_dict
    from_records
    from_arrow
    from_pandas

Eager functions
~~~~~~~~~~~~~~~
.. autosummary::
   :toctree: api/

   get_dummies
   concat
   repeat
   arg_where

